Tutoril k Emacsu.  Podmnky viz na konci.
Do etiny peloil Milan Zamazal <pdm@zamazal.org>.

Mte ped sebou tutoril k Emacsu.

Pkazy Emacsu obecn vyuvaj klvesu CONTROL (obas oznaovanou CTRL nebo
CTL) nebo klvesu META (obas oznaovanou EDIT nebo ALT).  Abychom tyto nzvy
nemuseli stle pst v plnm znn, budeme pouvat nsledujc zkratky:

 C-<chr>  znamen pidret klvesu CONTROL a stisknout znak <chr>.
          Tedy C-f znamen: pidrte klvesu CONTROL a stisknte f.
 M-<chr>  znamen pidret klvesu META, EDIT nebo ALT a stisknout <chr>.
          Pokud dnou z klves META, EDIT ani ALT nemte, tak msto toho
          stisknte a puste klvesu ESC a pot <chr>.  Klvesu ESC budeme
          znait <ESC>.

Dleit poznmka: prci s Emacsem ukonte stiskem C-x C-c (dva znaky).
Znaky ">>" na levm okraji zna msta, kde si mte vyzkouet pkaz.
Napklad:
<<Blank lines inserted here by startup of help-with-tutorial>>
[Prostedn st obrazovky je przdn zmrn. Text pokrauje ne.]
>>  Nyn stisknte C-v (view next screen) pro posun na dal obrazovku.
        (Smle do toho, provete to pidrenm klvesy CONTROL a stiskem v.)
	Od tto chvle byste toto mli provdt kdykoliv dotete zobrazenou
        obrazovku.

Vimnte si, e pi posuvu obrazovek vdy zstvaj zobrazeny dva dky
z pedchoz obrazovky; to poskytuje uritou nvaznost pi postupnm
ten textu.

Prvn vc, kterou potebujete vdt, je jak se v textu pohybovat
z jednoho msta na druh.  U vte, jak se posunout o jednu obrazovku
vped, pomoc C-v.  K pechodu o obrazovku zpt pouijte M-v
(pidrte klvesu META a stisknte v nebo stisknte <ESC>v, jestlie
nemte dnou z klves META, EDIT nebo ALT).

>>  Zkuste stisknout M-v a pak C-v, nkolikrt to zopakujte.


* SHRNUT
---------

K prohlen obrazovkovch strnek jsou uiten nsledujc pkazy:

	C-v	Posun o obrazovku vped
	M-v	Posun o obrazovku zpt
	C-l	Smazn obrazovky a znovuzobrazen celho textu,
		 pitom se text pod kurzorem pesune ke stedu obrazovky.
		 (Jedn se o CONTROL-L a ne CONTROL-1.)

>> Najdte kurzor a zapamatujte si, jak text je kolem nj.
   Pak stisknte C-l.
   Najdte kurzor znovu a vimnte si, e je kolem nj tent text.


* ZKLADN OVLDN KURZORU
---------------------------

Pohyb mezi obrazovkami je uiten, ale jak se pemstte na konkrtn
msto v textu na obrazovce?

Je toho mono doshnout nkolika zpsoby.  Nejzkladnjm zpsobem je
pouit pkaz C-p, C-b, C-f a C-n.  Kad z tchto pkaz pesune
kurzor na obrazovce o jeden dek nebo sloupec v danm smru.
Zde je tabulka znzorujc smr posuvu kurzoru vyvolan tmito tymi
pkazy:

			  Pedchoz dek, C-p
				  :
				  :
      Dozadu, C-b .... Momentln pozice kurzoru .... Dopedu, C-f
				  :
				  :
			 Nsledujc dek, C-n

>> Pesute kurzor na prostedn dek tohoto diagramu pomoc
   C-n nebo C-p.  Potom stisknte C-l, abyste na obrazovce vidli cel
   diagram vycentrovn.

Pravdpodobn se vm budou tyto pkazy snadno pamatovat podle
potench psmen anglickch nzv: P jako previous (pedchoz),
N jako next (nsledujc), B jako backward (zpt), F jako forward (vped).
Jsou to zkladn pkazy pro pohyb kurzoru a budete je pouvat
neustle, take by bylo velmi vhodn, kdybyste se je te nauili.

>> Provete nkolikrt C-n, abyste kurzor pesunuli na tento dek.

>> Posute kurzor dovnit dku pomoc nkolika C-f a pak nahoru stiskem C-p.
   Pozorujte, co C-p dl, kdy je kurzor uprosted dku.

Kad dek textu kon znakem novho dku, kter jej oddluje od dku
nsledujcho.  Znakem novho dku by ml bt ukonen i posledn dek
souboru (pestoe to Emacs nevyaduje).

>> Vyzkouejte C-b na zatku dku.  Kurzor by se ml pesunout na konec
   pedchozho dku, nebo jej tm pesunete pes znak novho dku.

C-f funguje analogicky jako C-b, tj. na konci dku dojde k pesunu na
dal dek.

>> Provete nkolik C-b, take uvidte, kde se nachz kurzor.
   Pak provdjte C-f, abyste se vrtili na konec dku.
   Pak provete jet jednou C-f, abyste se pesunuli na nsledujc
   dek.

Kdy kurzorem pejdete pes horn nebo doln okraj obrazovky, posune se
text za pslunm okrajem na obrazovku.  Tato vlastnost se nazv
"scrollovn".  Umouje pemstit kurzor na libovoln msto v textu,
ani by kurzor opustil obrazovku.

>> Zkuste posunout kurzor pod doln okraj obrazovky pomoc C-n a pozorujte,
   co se stane.

Jestlie je posun po znacch pli pomal, mete se pohybovat po
slovech.  M-f (META-f) provd posun o slovo vped a M-b provd posun
o slovo zpt.

>> Stisknte nkolikrt M-f a M-b.

Pokud se kurzor nachz uprosted slova, M-f provede pesun na konec
tohoto slova.  Nachz-li se kurzor v mezee mezi slovy, M-f provede
pesun na konec nsledujcho slova.  M-b pracuje analogicky v opanm
smru.

>> Stisknte nkolikrt M-f a M-b proloen s C-f a C-b, abyste vidli
   vsledky pkaz M-f a M-b provdnch z rznch mst uvnit slov a
   mezi nimi.

Vimnte si analogie mezi C-f a C-b na jedn stran a M-f a M-b na
stran druh.  Znaky s klvesou META jsou velmi asto vyuvny pro operace
vztahujc se k entitm definovanm jazykem (slova, vty, odstavce),
zatmco znaky s klvesou CONTROL pracuj na zkladnch prvcch
nezvislch na tom, co zrovna editujete (znaky, dky, apod.).

Tato analogie plat tak pro dky a vty: C-a a C-e provd pesun
na zatek a konec dku, M-a a M-e provd pesun na zatek a konec
vty.

>> Zkuste nkolikrt C-a a pot nkolikrt C-e.
   Zkuste nkolikrt M-a a pot nkolikrt M-e.

Vimnte si, e opakovan C-a nedl nic, zatmco opakovan M-a vdy
provd posun o dal vtu. Principu analogie to sice pli
neodpovd, ale pesto je toto chovn mono povaovat za pirozen.

Pozice kurzoru v textu se tak nazv "bod" ("point").  Abychom to
parafrzovali, kurzor je vidt na obrazovce v mst, kde je bod umstn
v textu.

Zde je pehled jednoduchch operac pro pohyb kurzoru vetn pkaz pro
pohyb mezi slovy a vtami:

	C-f	Pesun o znak vped
	C-b	Pesun o znak zpt

	M-f	Pesun o slovo vped
	M-b	Pesun o slovo zpt

	C-n	Pesun na nsledujc dek
	C-p	Pesun na pedchoz dek

	C-a	Pesun na zatek dku
	C-e	Pesun na konec dku

	M-a	Pesun zpt na zatek vty
	M-e	Pesun vped na konec vty

>> Vyzkouejte si te nkolikrt vechny tyto pkazy pro procvien.
   Jsou to nejpouvanj pkazy.

Dal dva dleit pkazy pro pohyb kurzoru jsou M-< (META men-ne),
kter provede pesun na zatek celho textu, a M-> (META vt-ne),
kter provede pesun na konec celho textu.

Na vtin terminl je "<" nad rkou, take pro vyvoln tohoto znaku
muste pout klvesu Shift.  Na tchto terminlech je tedy nutno pout
klvesu Shift i v ppad pkazu M-<; bez klvesy Shift byste provedli
M-rka.

>> Zkuste te M-< pro pesun na zatek tutorilu.
   Pouijte pak opakovan C-v, abyste se opt vrtili sem.

>> Zkuste te M-> pro pesun na konec tutorilu.
   Pouijte pak opakovan M-v, abyste se opt vrtili sem.

Kurzor mete pesouvat tak pomoc kurzorovch klves (klvesy
se ipkami), pokud je v terminl m.  My vak doporuujeme nauit se
C-b, C-f, C-n a C-p, a to ze t dvod.  Za prv, tyto klvesy funguj
na vech typech terminl.  Za druh, jakmile jednou zskte cvik
v pouvn Emacsu, zjistte, e pouvn tchto CTRL znak je
rychlej ne pouvn kurzorovch klves (protoe nemuste pesouvat
ruku z psac pozice).  Za tet, zvyknete-li si pouvat tyto CTRL-znak
pkazy, snadno se naute pouvat jin pokroil pkazy pro pohyb
kurzoru.

Vtina pkaz Emacsu akceptuje numerick argument; ten pro vtinu
pkaz slou jako opakova.  Poet opakovn pkazu zadte
prostednictvm stisku C-u nsledovanho stiskem pslunch slic ped
vyvolnm pkazu.  Mte-li META (nebo EDIT i ALT) klvesu, existuje
alternativn monost zadn numerickho argumentu: pidrte klvesu META
a stisknte pslun slice.  Doporuujeme nauit se C-u metodu,
protoe ta funguje na jakmkoliv terminlu.

Napklad C-u 8 C-f provede pesun o osm znak vped.

Vtina pkaz pouv numerick argument jako opakova.  Jist
vjimen pkazy jej pouvaj jinm zpsobem.  Mezi tyto vjimky pat
C-v a M-v.  Dostanou-li numerick argument, posunou obrazovku nahoru
nebo dol o odpovdajc poet dk msto obrazovek.  Napklad
C-u 4 C-v posune obrazovku o 4 dky.

>> Zkuste te stisknout C-u 8 C-v.

To by mlo posunout obrazovku o 8 dk nahoru.  Pokud byste ji chtli
posunout zpt dol, mete dt argument pkazu M-v.

Pouvte-li X Window, mli byste mt na lev stran emacsovho okna
vysokou obdlnkovou oblast, nazvanou scrollbar.  Mete pak text
posouvat kliknm my na scrollbar.

>> Zkuste stisknout prostedn tlatko na vrcholu zvraznn oblasti
   uvnit scrollbaru.  To by mlo text posunout na pozici danou tm, jak
   vysoko nebo nzko jste kliknuli.

>> Zkuste pi stisknutm prostednm tlatku posouvat my nahoru a
   dol.  Uvidte, jak se text posouv nahoru a dol podle toho, jak
   posouvte my.


* KDY EMACS NEREAGUJE
----------------------

Jestlie Emacs pestane reagovat na vae pkazy, mete probhajc
innost bezpen zastavit pomoc C-g.  Pomoc C-g mete zastavit
pkaz, jeho provdn trv pli dlouho.

C-g mete pout tak pro odstrann numerickho argumentu pkazu,
kter nechcete dokonit.

>> Stisknte C-u 100 pro vytvoen numerickho argumentu 100 a pak
   stisknte C-g.  Nyn stisknte C-f.  Ml by bt proveden posun
   o prv jeden znak, protoe jste argument zruili prostednictvm
   C-g.

Pokud jste omylem stiskli <ESC>, mete se jej zbavit pomoc C-g.


* DEAKTIVOVAN PKAZY
----------------------

Nkter pkazy Emacsu jsou "deaktivovan" ("disabled"), aby je
zanajc uivatel nemohli vyvolat nhodn.

Pokud vyvolte nkter z deaktivovanch pkaz, Emacs zobraz hlen
oznamujc, kter pkaz to byl, s dotazem, zda chcete tento pkaz
provst.

Pokud opravdu chcete pkaz vyzkouet, stisknte mezernk jako odpov
na tuto otzku.  Obyejn, jestlie nechcete deaktivovan pkaz
provst, odpovzte na tuto otzku pomoc "n".

>> Stisknte C-x C-l (co je deaktivovan pkaz),
   pak na otzku odpovzte n.


* OKNA
------

Emacs me mt nkolik oken (windows), z nich kad zobrazuje svj
vlastn text.  Jak vce oken pouvat, objasnme pozdji.  Nyn chceme
objasnit, jak se zbavit nadbytench oken a vrtit se do zkladn
jednookenn editace.  Je to jednoduch:

	C-x 1	Jedno okno (tj. zruen vech ostatnch oken)

Tedy vloen CONTROL-x nsledovan slic 1.  C-x 1 roz okno
obsahujc kurzor pes celou obrazovku.  Zru to vechna ostatn okna.

>> Stisknte C-h k C-f.
   Pozorujte, jak se aktuln okno zmen a objev se nov okno za
   elem zobrazen dokumentace k pkazu C-f.

>> Stisknte C-x 1 a pozorujte, jak okno s dokumentac zmiz.


* VKLDN A MAZN
-------------------

Chcete-li vloit text, prost jej napite.  Znaky, kter vidte,
jako A, 7, *, atd., jsou Emacsem chpny jako text a vkldny okamit.
Pro vloen znaku novho dku stisknte <Return> (klvesu Enter).

Posledn znak, kter jste napsali, mete smazat stiskem <Delete>.
<Delete> je klvesa, kter me bt na klvesnici oznaena "Del".
V nkterch ppadech jako <Delete> slou klvesa "Backspace", avak ne
vdy!

Obecnji, <Delete> mae znak bezprostedn ped momentln pozic
kurzoru.

>> Provete to te -- napite nkolik znak a pak je smate nkolika
   stisky <Delete>.  Nebojte se zmn v tomto souboru; originln
   tutoril se nezmn.  Toto je vae osobn kopie.

Kdy se dek textu zvt natolik, e peshne jeden dek obrazovky,
je zobrazen na vce dcch obrazovky.  dek textu, kter pokrauje na
dalm dku obrazovky, je indikovn zptnm lomtkem ("\") na pravm
okraji obrazovky.

>> Vkldejte text, a doshnete pravho okraje, a pokraujte ve vkldn.
   Objev se vm pokraovac dek.

>> Pouijte <Delete> pro smazn textu, a se dek textu opt vejde na
   jeden dek obrazovky.  Pokraovac dek zmiz.

Znak novho dku mete smazat jako kterkoliv jin znak.  Smazn
znaku novho dku mezi dvma dky zpsob jejich spojen do jedinho
dku.  Je-li vsledn dek pli dlouh na to, aby se veel na ku
obrazovky, bude zobrazen pokraovacm dkem.

>> Pesute kurzor na zatek dku a stisknte <Delete>.  To tento
   dek spoj s dkem pedchozm.

>> Stisknte <Return> pro znovuvloen smazanho znaku novho dku.

Vzpomete si, e vtina pkaz Emacsu me dostat poet opakovn;
vetn textovch znak.  Opakovn textovch znak je vlo nkolikrt.

>>  Vyzkouejte si to te -- stisknte C-u 8 * pro vloen ********.

Te u znte nejzkladnj zpsoby, jak nco v Emacsu napsat a jak
opravovat chyby.  Mete ovem tak mazat po slovech nebo po dcch.
Zde je shrnut operac pro mazn textu:

	<Delete>     Smazn znaku bezprostedn ped kurzorem
	C-d   	     Smazn znaku nsledujcho za kurzorem

	M-<Delete>   Zruen slova bezprostedn ped kurzorem
	M-d	     Zruen slova nsledujcho za kurzorem

	C-k	     Zruen textu od pozice kurzoru do konce dku
	M-k	     Zruen textu do konce aktuln vty

Vimnte si, e <Delete> a C-d, resp. M-<Delete> a M-d, roziuj
paralelu zapoatou C-f a M-f (pravda, <Delete> opravdu nen CONTROL
znak, ale netrapme se tm).  C-k a M-k jsou jako C-e a M-e ve smyslu
vztahu dk k vtm.

Libovolnou st bufferu mete t zruit nsledujc metodou.
Pesute se na jeden konec tto sti a stisknte C-@ nebo C-SPC
(libovolnou z tchto kombinac). (SPC oznauje mezernk.)  Pesute
se na druh konec tto sti a stisknte C-w.  Text mezi tmito
pozicemi bude zruen.

>> Pesute kurzor na psmeno L na zatku pedchozho odstavce.
>> Stisknte C-SPC.  Emacs by ml ve spodnm dku obrazovky
   zobrazit zprvu "Mark set".
>> Pesute kurzor na psmeno c ve slov "konec" na druhm dku
   odstavce.
>> Stisknte C-w.  Text zanajc psmenem L a konc ped psmenem
   c bude zruen.

Uvdomte si, e rozdl mezi "ruenm" ("killing") a "maznm"
("deleting") je ten, e "zruen" vci mohou bt zpt vhozeny, zatmco
"smazan" nikoliv.  Obecn pkazy, kter mohou smazat vt mnostv
textu, ukldaj text, zatmco pkazy, kter maou jedin znak nebo
pouze przdn dky a mezery, mazan text neukldaj.

>> Pesute kurzor na zatek neprzdnho dku.
   Pak stisknte C-k pro zruen textu na tomto dku.
>> Stisknte C-k podruh.  Uvidte, e to zru znak novho dku, kter
   je za tmto dkem.

Vimnte si, e jedno C-k zru obsah dku a druh C-k zru dek
samotn a posune vechny dal dky nahoru.  C-k zpracovv numerick
argument speciln: zru odpovdajc poet dk VETN jejich
obsahu.  To u nen opakovn.  C-u 2 C-k zru dva dky a jejich
obsah; dvojit stisk C-k by toto obvykle neudlal.

Vracen textu zpt se nazv "vhazovn" ("yanking").  (Pedstavte
si optovn vhazovn, vracen dve odstrannho textu zptky.)
Zruen text mete vhodit bu na stejn msto, kde byl zruen,
nebo na jin msto v bufferu, nebo dokonce i do jinho souboru.
Text mete vhodit i vcekrt, vytvte tak jeho dal kopie.

Pkazem pro vhazovn je C-y.  Tento pkaz vlo posledn smazan
text na pozici, na kter se nachz kurzor.

>> Zkuste to; stisknte C-y pro vhozen textu zpt.

Stisknete-li nkolikrt C-k po sob, vechen smazan text je uloen
spolen tak, aby bylo mon vhodit zpt vechny dky najednou.

>> Stisknte nkolikrt C-k.

Nyn obnovte posledn zruen text:

>> Stisknte C-y.  Pak posute kurzor o nkolik dk ne a stisknte
   C-y znova.  Nyn vidte, jak lze text koprovat.

Co kdy mte njak text, kter byste rdi vhodili zpt a pak zrute
nco jinho?  C-y by vloilo posledn zruen text.  Avak pedchoz
text nen ztracen.  Mete jej zskat zpt pouitm pkazu M-y.  Pot,
co provedete C-y pro zskn poslednho zruenho textu, stisk M-y
vymn tento vhozen text za pedchoz zruen text.  Dalmi a
dalmi stisky M-y dostvte pedchzejc a pedchzejc zruen
texty.  Kdy doshnete textu, kter hledte, nemuste s nm pro jeho
uchovn nic dalho provdt.  Jednodue vhozen text ponechejte, kde
je, a pokraujte v editaci.

Pokud opakujete M-y dostaten dlouho, dostanete se zptky k vchozmu
bodu (posledn zruenmu textu).

>> Zrute dek, pesute kurzor nkam jinam a zrute jin dek.
   Pak provete C-y pro vrcen druhho zruenho dku.
   Pak provete M-y a vhozen dek bude nahrazen prvnm zruenm dkem.
   Opakujte M-y a pozorujte, co dostvte.  Pokraujte v tom, dokud se
   znovu neobjev druh zruen dek a pak nkolik dalch.
   Chcete-li, mete zkusit pedat M-y kladn a zporn argumenty.


* UNDO
------

Jestlie provedete v textu zmnu a pak zjistte, e to byl omyl, mete
zmnu vrtit pkazem undo, C-x u.

C-x u obvykle vrt zmny proveden jednm pkazem; pokud C-x u
zopakujete nkolikrt za sebou, kad opakovn vrt jeden dal
pkaz.

Jsou ale dv vjimky: pkazy, kter nemn text, se nepotaj (to
zahrnuje pkazy pro pohyb kurzoru a scrollovn) a znaky vkldajc
samy sebe jsou obvykle zpracovvny ve skupinch a po 20.  (To je kvli
tomu, aby se zredukoval poet C-x u nutnch pro vrcen vkldanho
textu.)

>> Zrute tento dek pomoc C-k, stisknte pak C-x u a dek by se ml
   znovu objevit.

Alternativn undo pkaz je C-_; pracuje stejn jako C-x u, je vak
mn pracn jej aplikovat nkolikrt za sebou.  Nevhodou C-_ je, e
na nkterch klvesnicch nen zejm, jak jej vyvolat.  To je dvod,
pro nabzme i C-x u.  Na nkterch terminlech mete C-_ vyvolat
stiskem / pi stisknutm CTRL.

Numerick argument pro C-_ a C-x u funguje jako poet opakovn.

Pomoc pkazu undo mete vrtit zruen stejn jako smazan text.
Rozdl mezi maznm a ruenm textu ovlivuje monost vhozen tohoto
textu pomoc C-y, neovlivuje monosti pkazu undo.


* SOUBORY
---------

Aby text, kter editujete, zstal trvale uchovn, muste jej uloit do
souboru.  Jinak by byl po ukonen Emacsu ztracen.  Svoji editaci
spojte se souborem "vyhlednm" ("finding") souboru.  (Tak se to
nazv "navtven" ("visiting") souboru.)

Vyhledn souboru znamen, e vidte jeho obsah v Emacsu.  V mnoha
ohledech je to, jako byste editovali pmo ten soubor.  Nicmn zmny,
kter prostednictvm Emacsu inte, se nestanou trvalmi, dokud tyto
zmny do souboru "neulote" ("save").  Tm se zamez nechtnmu ponechn
sten zmnnho souboru v systmu.  Dokonce i kdy soubor ulote,
Emacs uchov pvodn soubor pod zmnnm nzvem pro ppad, e byste
zjistili, e vae pravy byly chybn.

Kdy se podvte do doln sti obrazovky, uvidte dek, kter zan a
kon pomlkami a na zatku m "2J:-- TUTORIAL.cs" nebo nco podobnho.
Tato st obrazovky obvykle obsahuje jmno souboru, kter je prv
navtven.  Zrovna te mte navtven soubor nazvan "TUTORIAL.cs",
kter je va osobn mrac kopi tutorilu Emacsu.  Kdy v Emacsu
vyhledte soubor, jeho jmno se objev pesn na tom mst.

Pkazy pro vyhledvn a ukldn soubor se na rozdl od ostatnch
pkaz, kter jste se zatm nauili, skldaj ze dvou znak.  Oba
zanaj znakem CONTROL-x.  Existuje cel ada pkaz zanajcch na
CONTROL-x; mnoho z nich pracuje se soubory, buffery a podobnmi vcmi.
Tyto pkazy jsou dlouh dva, ti nebo tyi znaky.

Dal vc ohledn pkazu pro vyhledn souboru je to, e muste ct,
kter jmno souboru chcete.  kme, e pkaz "te argument
z terminlu" (v tomto ppad je argumentem jmno souboru).  Pot co
vyvolte pkaz

	C-x C-f   Vyhledn souboru

Emacs se vs zept na jmno souboru.  Jmno souboru, kter pete, se
objevuje ve spodnm dku obrazovky, kter se v tto situaci nazv
minibuffer.  Pro editaci jmna souboru mete pouvat obvykl editan
pkazy Emacsu.

Zadvn jmna souboru (obecn kterkoliv vstup z minibufferu) mete
zruit pkazem C-g.

>> Stisknte C-x C-f a pak C-g.  To minibuffer zru a takt to zru
   pkaz C-x C-f, kter minibuffer pouil.  Take nevyhledte dn
   soubor.

Po napsn jmna souboru stisknte <Return>.
Pkaz C-x C-f pak zane pracovat a vyhled soubor, kter jste zvolili.
Po skonen pkazu C-x C-f minibuffer zmiz.

Po mal chvilce se obsah souboru objev na obrazovce a mete jej
editovat.  Kdy chcete zmny trvale uloit, pouijte pkaz

	C-x C-s   Uloen souboru

To zkopruje text z Emacsu do souboru.  Kdy to provedete poprv, Emacs
pejmenuje pvodn soubor na soubor s novm jmnem, aby nebyl ztracen.
Nov jmno je vytvoeno pidnm "~" na konec pvodnho jmna souboru.

Kdy je ukldn dokoneno, Emacs zobraz jmno zapsanho souboru.
Mli byste ukldat rozumn asto, abyste neztratili pli mnoho prce
v ppad pdu systmu.

>> Stisknte C-x C-s pro uloen va kopie tutorilu.
   Mlo by to zobrazit "Wrote ...TUTORIAL.cs" ve spodnm dku obrazovky.

Existujc soubor mete vyhledat, abyste jej mohli prohlet nebo
editovat.  Mete tak vyhledat soubor, kter jet neexistuje.  To je
zpsob, jakm lze vytvoit soubor v Emacsu: vyhledejte soubor, kter
bude na zatku przdn a pak zante vkldat text uren pro tento
soubor.  Kdy podte o uloen, Emacs skuten vytvo soubor
s textem, kter jste vloili.  Od t chvle se pak mete ctit, jako
kdybyste editovali ji existujc soubor.


* BUFFERY
---------

Jestlie vyhledte pomoc C-x C-f druh soubor, prvn soubor v Emacsu
zstv.  Mete se do nj zpt pepnout jeho optovnm vyhlednm
pomoc C-x C-f.  Tmto zpsobem mete do Emacsu dostat pomrn hodn
soubor.

>> Vytvote soubor pojmenovan "foo" stiskem C-x C-f foo <Return>.
   Potom vlote njak text, zeditujte jej a ulote "foo" stiskem C-x C-s.
   Nakonec stisknte C-x C-f TUTORIAL.cs <Return>, m se vrtte zpt do
   tutorilu.

Emacs ukld text kadho souboru do objektu nazvanho "buffer".
Vyhledn souboru vytvo v Emacsu nov buffer.  Chcete-li vidt seznam
buffer, kter momentln existuj ve vaem procesu Emacs, stisknte:

	C-x C-b   Seznam buffer

>> Zkuste te C-x C-b.

Podvejte se, e kad buffer m v seznamu jmno a me tam mt tak jmno
souboru, jeho text obsahuje.  Nkter buffery neodpovdaj souborm.
Napklad buffer pojmenovan "*Buffer List*" nem dn soubor.  Je to
buffer, kter obsahuje seznam buffer vytvoen pomoc C-x C-b.
JAKKOLIV text, kter vidte v emacsovm okn, je vdy soust
njakho bufferu.

>> Stisknte C-x 1, abyste se zbavili seznamu buffer.

Pokud provedete zmny textu jednoho souboru a pak vyhledte jin soubor,
nezpsob to uloen prvnho souboru.  Jeho zmny zstvaj v Emacsu
uchovny v jemu odpovdajcm bufferu.  Vytvoen a editace druhho
souboru nem dn vliv na buffer prvnho souboru.  To je velmi
uiten, ale tak to znamen, e potebujete vhodn zpsob, jak uloit
buffer prvnho souboru.  Nutnost pepnout se zptky pomoc C-x C-f, aby
jej bylo mono uloit prostednictvm C-x C-s, by byla nemstn
obtujc.  Take mme

	C-x s     Uloen nkterch buffer

C-x s se vs zept na kad buffer, kter obsahuje zmny, kter jste
neuloili.  Pro kad takov buffer se vs zept, zda jej m uloit.

>> Vlote dek textu a pak stisknte C-x s.
   Mli byste bt dotzni, zda m bt uloen buffer nazvan TUTORIAL.cs.
   Odpovzte na tuto otzku ano (yes) stiskem "y".


* ROZIOVN SADY PKAZ
--------------------------

Existuje mnohem, mnohem vce pkaz Emacsu, ne kter by vbec mohly
bt rozmstny na vechny CONTROL a META znaky.  Emacs tento problm
obchz prostednictvm X (eXtend) pkazu.  Ten vznik dvma zpsoby:

	C-x	Znakov eXtend.  Nsledovn jednm znakem.
	M-x	Pojmenovan pkaz eXtend.  Nsledovn dlouhm nzvem.

To jsou pkazy, kter jsou obecn uiten, avak mn asto pouvan
ne ty, kter jste se ji nauili.  U jste vidli dva z nich: souborov
pkazy C-x C-f pro vyhledn a C-x C-s pro uloen.  Jin pklad je
pkaz pro ukonen Emacsu -- tj. pkaz C-x C-c.  (Nemjte obavy
o ztrtu zmn, kter jste provedli; C-x C-c nabdne uloen kadho
zmnnho souboru, ne Emacs ukon.)

C-z je pkaz na *doasn* oputn Emacsu -- mete se po nm do
sputnho Emacsu vrtit.

Na systmech, kter to umouj, C-z Emacs "pozastav"; tzn. vrt vs
do shellu, avak Emacs neukon.  V nejbnjch shellech se mete do
Emacsu vrtit pkazem `fg' nebo pomoc `%emacs'.

Na systmech, kter pozastavovn proces nemaj implementovno, C-z
vytvo subshell bc pod Emacsem, aby vm dal anci spustit jin
programy a pak se do Emacsu vrtit; neprovede tedy prav oputn
Emacsu.  V tom ppad je obvyklou cestou nvratu ze subshellu do Emacsu
shellovsk pkaz `exit'.

Chvle pro pouit C-x C-c nastane, kdy se chystte odhlsit ze
systmu.  Sprvn je to tak pi ukonovn Emacsu vyvolanho potovnm
programem a rznmi jinmi utilitami, protoe ty nemus vdt, jak si
poradit s pozastavenm Emacsu.  Nicmn za normlnch okolnost, pokud
se nechystte odlogovat, je lpe Emacs pozastavit pomoc C-z ne jej
ukonit.

Existuje mnoho C-x pkaz.  Zde je seznam tch, kter jste se ji nauili:

	C-x C-f		Vyhledn souboru
	C-x C-s		Uloen soubor
	C-x C-b		Seznam buffer
	C-x C-c		Ukonen Emacsu
	C-x u		Undo

Pojmenovan eXtended pkazy jsou pkazy, kter jsou pouvny jet
mn, nebo pkazy, kter jsou pouvny jenom v jistch mdech.
Pkladem je pkaz replace-string, kter globln nahrad jeden etzec
jinm.  Kdy stisknete M-x, vype se na spodnm dku obrazovky prompt
M-x a vy byste mli zadat jmno pkazu; v tomto ppad
"replace-string".  Jednodue napite "repl s<TAB>" a Emacs nzev dopln.
Dokonete zadvn jmna pkazu pomoc <Return>.

Pkaz replace-string vyaduje dva argumenty -- etzec, kter m bt
nahrazen, a etzec, kter jej m nahradit.  Kad argument muste
ukonit pomoc <Return>.

>> Pesute kurzor na przdn dek dva dky pod tmto.
   Pak napite M-x repl s<Return>zmnil<Return>modifikoval<Return>.

   Vimnte si, jak se tento dek zmnil: nahradili jste slovo
   z-m--n-i-l slovem "modifikoval", kdekoliv se za aktuln pozic
   kurzoru vyskytlo.


* AUTOMATICK UKLDN
----------------------

Jestlie jste provedli zmny v souboru, ale nemte je jet uloeny,
mohou bt v ppad pdu systmu ztraceny.  Aby vs Emacs od toho
uchrnil, periodicky zapisuje "auto save" soubor pro kad soubor, kter
editujete.  Jmno auto save souboru m na zatku a na konci #;
napklad jestlie se v soubor jmenuje "hello.c", jeho auto save
soubor se jmenuje "#hello.c#".  Kdy soubor ulote normlnm zpsobem,
Emacs auto save soubor smae.

Jestlie dojde k pdu systmu, mete svoji editaci obnovit z auto-save
souboru, a to normlnm vyhlednm souboru (toho, kter jste editovali,
ne auto save souboru) a nslednou aplikac M-x recover file<return>.
Na dost o potvrzen odpovzte zadnm yes<return> pro pokraovn a
obnoven auto-save dat.


* ECHO OBLAST
-------------

Kdy Emacs vid, e pete pkazy pomalu, ukazuje vm je ve spodn
sti obrazovky v oblasti nazvan "echo oblast".  Echo oblast obsahuje
doln dek obrazovky.


* STAVOV DEK
---------------

dek bezprostedn nad echo oblast se nazv "stavov dek" ("mode line").
Stavov dek k nco jako:

2J:** TUTORIAL.cs       (Fundamental)--L670--58%----------------

Tento dek podv uitenou informaci o stavu Emacsu a textu, kter
editujete.

U vte, co znamen jmno souboru -- je to soubor, kter jste vyhledali.
-NN%-- oznauje vai aktuln pozici v textu; k, e NN procent textu
je nad hornm okrajem obrazovky.  Je-li zatek souboru na obrazovce, je
zde --Top-- a ne --00%--.  Je-li konec textu na obrazovce, je zde
--Bot--.  Jestlie se dvte na tak mal text, e se cel vejde na
obrazovku, stavov dek k --All--.

Hvzdiky pobl zatku znamenaj, e jste text zmnili.  Tsn po
vyhledn nebo uloen souboru v tto sti stavovho dku nejsou dn
hvzdiky, pouze pomlky.

st stavovho dku v zvorkch k, v jakch editanch mdech se
nachzte.  Implicitn md je Fundamental, co je ten, kter momentln
pouvte.  Je pkladem hlavnho mdu ("major mode").

Emacs m celou adu hlavnch md.  Nkter z nich jsou ureny pro
editaci rznch programovacch jazyk a/nebo text jako teba Lisp md,
Text md, atd.  V libovolnm okamiku je aktivn prv jeden hlavn md a
jeho jmno lze nalzt ve stavovm dku na mst, kde je te
"Fundamental".

Kad hlavn md mn chovn nkterch pkaz.  Napklad existuj
pkazy pro vytven koment v programu, a protoe kad programovac
programovac jazyk m jinou pedstavu o tom, jak m koment vypadat,
mus kad hlavn md vkldat komente jinak.  Kad hlavn md je
vlastn jmno extended pkazu, kterm se do tohoto mdu mete
pepnout.  Napklad M-x fundamental-mode je pkaz pro pepnut se do
Fundamental mdu.

Chystte-li se editovat esk text, jako teba tento soubor,
pravdpodobn byste mli pout Text md.
>> Napite M-x text-mode<Return>.

Nebojte se, dn z pkaz, kter jste se nauili, chovn Emacsu nijak
vznamn nezmn.  Mete si ale vimnout, e M-f a M-b nyn pracuj
s apostrofy jako se soustmi slov.  Pedtm, ve Fundamental mdu, M-f a
M-b pracovaly s apostrofy coby oddlovai slov.

Hlavn mdy obvykle dlaj men zmny, jako byla tato: pkazy vtinou
dlaj "tot", ale v kadm hlavnm mdu pracuj troku jinak.

Dokumentaci k aktulnmu hlavnmu mdu si mete zobrazit stiskem C-h m.

>> Jednou nebo nkolikrt pouijte C-u C-v, abyste tento dek dostali
   k vrcholu obrazovky.
>> Stisknte C-h m, abyste vidli, jak se Text md li od Fundamental
   mdu.
>> Stisknte C-x 1 pro odstrann dokumentace z obrazovky.

Hlavn mdy se nazvaj hlavn proto, e tak existuj vedlej mdy
(minor modes).  Vedlej mdy nejsou alternativou k hlavnm mdm, nbr
jejich mal modifikace.  Kad vedlej md me bt zapnut nebo vypnut
sm o sob nezvisle na vech ostatnch vedlejch mdech a nezvisle na
hlavnm mdu.  Take nemuste pouvat dn vedlej md nebo mete
pouvat jeden vedlej md nebo libovolnou kombinaci nkolika
vedlejch md.

Jednm z velmi uitench vedlejch md, zejmna pro editaci eskch
text, je Auto Fill md.  Kdy je tento md zapnut, Emacs zalom dek
mezi dvma slovy, kdykoliv vkldte text a dek se stane pli
dlouhm.

Auto Fill md mete zapnout provedenm M-x auto-fill-mode<Return>.
Je-li tento md zapnut, mete jej vypnout provedenm M-x
auto-fill-mode<Return>.  Je-li md vypnut, tento pkaz jej zapn,
a je-li md zapnut, tak jej tento pkaz vypn.  kme, e tento
pkaz pepn ("toggles") tento md.

>> Napite te M-x auto-fill-mode<Return>.  Pak vkldejte "asdf " stle
   dokola tak dlouho, a uvidte, jak se vkldan dek rozdl na dva
   dky.  Do textu muste vkldat mezery proto, e Auto Fill md
   zalamuje dky pouze v mezerch.

Okraj je obvykle nastaven na 70 znak, ale mete to zmnit pkazem
C-x f.  Hodnotu okraje, kterou si pejete, byste mli pedat jako
numerick argument.

>> Napite C-x f s argumentem 20.  (C-u 2 0 C-x f).
   Pak pite njak text a pozorujte, jak Emacs vypluje dky po
   20 znacch.  Pak nastavte okraj zptky na 70 optovnm pouitm
   C-x f.

Jestlie provedete zmny uprosted odstavce, Auto Fill md jej
nepeformtuje.
Pro peformtovn odstavce stisknte M-q (META-q) s kurzorem uvnit
odstavce.

>> Pesute kurzor do pedchozho odstavce a stisknte M-q.


* VYHLEDVN
-------------

Emacs um v textu vyhledvat etzce (tj. skupiny spojench znak nebo
slov) smrem vped nebo vzad.  Hledn etzce je pkaz pesunujc
kurzor; pesune kurzor na nejbli msto, kde se tento etzec nachz.

Vyhledvac pkaz Emacsu se li od vyhledvacch pkaz vtiny
editor v tom smyslu, e je "inkrementln".  To znamen, e vyhledvn
se provd u v okamiku, kdy zadvte vyhledvac etzec.

Pkaz pro zahjen hledn vped je C-s a pro hledn vzad C-r.
ALE POZOR!  Nezkouejte to jet.

Kdy stisknete C-s, uvidte v echo oblasti prompt "I-search".  To vm
k, e Emacs se nachz ve stavu, kter se nazv inkrementln hledn,
a ek, a mu zadte, co chcete hledat.  <RET> hledn ukon.

>> Nyn zahajte hledn stiskem C-s.  POMALU, psmeno po psmenu, pite
   slovo 'kurzor'.  Po kadm psmenu si vimnte, co se dje s kurzorem.
   Te jste vyhledali "kurzor" poprv.
>> Stisknte C-s znovu, abyste nalezli dal vskyt "kurzor".
>> Nyn tyikrt stisknte <Delete> a pozorujte, jak se kurzor
   pesunuje.
>> Stisknte <RET> pro ukonen hledn.

Vidli jste, co se stalo?  Emacs se v inkrementlnm hledn pokou
pejt na dal vskyt etzce, kter jste dosud napsali.  Chcete-li
pejt na dal vskyt 'kurzor', jednodue stisknte C-s znovu.
Jestlie u dn takov vskyt nen, Emacs ppne a ekne vm, e
hledn momentln "selhv", C-g hledn ukon.

POZNMKA: Na nkterch systmech stisk C-s zpsob ztuhnut
obrazovky a nevidte dn dal vstup z Emacsu.  To znamen, e
"vlastnost" operanho systmu zvan "flow control" zachycuje C-s a
nepropust jej k Emacsu.  Pro odtuhnut obrazovky stisknte C-q.  Pak
v sekci "Spontaneous Entry to Incremental Search" v manulu Emacsu
vyhledejte radu, jak se vypodat s touto "vlastnost".

Jestlie uprosted inkrementlnho hledn stisknete <Delete>, uvidte,
e posledn znak v hledanm etzci zmiz a hledn se vrac na posledn
msto hledn.  Pedpokldejme napklad, e jste napsali "c", abyste
nali prvn vskyt "k".  Jestlie nyn stisknete "u", kurzor se pesune na
prvn vskyt "ku".  Te stisknte <Delete>.  To vymae "u" z hledanho
etzce a kurzor se pesune zpt na prvn vskyt "k".

Jestlie uprosted hledn stisknete CONTROL nebo META znak (s nkolika
vjimkami -- znaky, kter jsou speciln v hledn, jako C-s a C-r),
hledn se ukon.

C-s zahajuje hledn, kter hled jakkoliv vskyt hledanho etzce ZA
aktuln pozic kurzoru.  Chcete-li nco hledat v pedchzejcm textu,
stisknte C-r msto C-s.  Ve, co jsme ekli o C-s, plat tak o C-r
krom toho, e smr hledn je opan.


* VCE OKEN
-----------

Jednou z pknch vlastnost Emacsu je to, e me na obrazovce zobrazit
vce oken souasn.

>> Pesute kurzor na tento dek a stisknte C-u 0 C-l.

>> Te stisknte C-x 2, co rozdl obrazovku na dv okna.
   Ob okna zobrazuj tento tutoril.  Kurzor zstv navrchu okna.

>> Tisknte C-M-v pro scrollovn spodnho okna.
   (Nemte-li skutenou klvesu META, stisknte ESC C-v.)

>> Stisknte C-x o ("o" jako "other") pro pesun kurzoru do dolnho okna.

>> Pouijte C-v a M-v ve spodnm okn pro jeho scrollovn.
   Pokraujte ve ten tchto instrukc v hornm okn.

>> Znovu stisknte C-x o pro pesun kurzoru zpt do hornho okna.
   Kurzor v hornm okn je pesn na mst, kde byl pvodn.

Mete dle pouvat C-x o pro pepnn mezi okny.  Kad okno m svoji
vlastn pozici kurzoru, ale jenom jedno okno kurzor skuten zobrazuje.
Vechny obvykl editan pkazy plat pro okno, ve kterm se nachz
kurzor.  Toto okno nazvme "aktivn okno" ("selected window").

Pkaz C-M-v je velmi uiten, jestlie v jednom okn editujete text a
druh okno pouvte pouze pro pehled.  Mete kurzor nechvat stle
v okn, kde editujete, a postupovat po druhm okn pomoc C-M-v.

C-M-v je pkladem CONTROL-META znaku.  Mte-li skutenou META klvesu,
mete vyvolat C-M-v pidrenm obou klves CTRL a META pi stisku v.
Nezle na tom, zda je prvn stisknuta CTRL nebo META, protoe ob tyto
klvesy funguj jako modifiktory klves, kter tisknete.

Pokud nemte skutenou META klvesu, mete msto n pout ESC, na
poad zle: muste stisknout ESC a nsledn CTRL-v; CTRL-ESC v by
nefungovalo.  To proto, e ESC je samostatn znak, nikoliv modifiktor.

>> Stisknte C-x 1 (v hornm okn), abyste se zbavili dolnho okna.

(Kdybyste C-x 1 stiskli v dolnm okn, odstranilo by to horn okno.
Chpejte tento pkaz jako "ponechej prv jedno okno -- to, ve kterm
zrovna jsem".)

Nemuste v obou oknech zobrazovat tent buffer.  Jestlie pouijete
C-x C-f pro vyhledn souboru v jednom z oken, druh okno se nezmn.
Mete vyhledvat soubory v obou oknech nezvisle.

Zde je dal zpsob, jak vyut dv okna ke zobrazen dvou rznch vc:

>> Stisknte C-x 4 C-f nsledovan jmnem nkterho z vaich soubor.
   Dokonete to pomoc <Return>.  Vidte zadan soubor v dolnm okn.
   Pesunul se tam i kurzor.

>> Stisknte C-x o pro pesun zpt do hornho okna a C-x 1 pro smazn
   dolnho okna.


* REKURZIVN EDITAN ROVN
----------------------------

Obas se dostanete do neho, co se nazv "rekurzivn editan rove"
("recursive editing level").  To je indikovno hranatmi zvorkami ve
stavovm dku obklopujcmi zvorky okolo jmna hlavnho mdu.
Napklad mete vidt [(Fundamental)] msto (Fundamental).

Abyste se dostali z rekurzivn editan rovn, stisknte ESC ESC ESC.
To je obecn "vyskakovac" pkaz.  Mete jej pout t pro odstrann
nkterch oken a vyskoen z minibufferu.

>> Stisknte M-x, abyste se dostali do minibufferu; pak stisknte
   ESC ESC ESC, abyste se z nj dostali ven.

Z rekurzivn editan rovn nemete vyskoit pomoc C-g.  To proto, e
C-g je vyuvno pro ruen pkaz a argument UVNIT rekurzivn
editan vrstvy.


* ZSKN DAL NPOVDY
------------------------

V tomto tutorilu jsme se pokusili poskytnout vm dostatek informac,
abyste mohli zat Emacs pouvat.  V Emacsu je toho tolik, e by bylo
nemon to zde vechno objasnit.  Nicmn se o Emacsu mete nauit
vce, protoe m mnoho uitench vlastnost.  Emacs nabz pkazy pro
ten dokumentace svch pkaz.  Vechny tyto "help" pkazy
zanaj znakem CONTROL-h, kter se nazv "help znak".

Pro pouit vlastnost npovdy stisknte znak C-h a pak znak kajc,
jak druh npovdy dte.  Jste-li OPRAVDU ztraceni, stisknte C-h ? a
Emacs vm sdl, jak druhy npovdy vm me poskytnout.  Jestlie
jste stiskli C-h a pak jste se rozhodli, e dnou npovdu nechcete,
jednodue to zrute stiskem C-g.

(Na nkterch potach je vznam znaku C-h zmnn.  To by opravdu
nemlo bt obecnm nastavenm pro vechny uivatele, take mte prvo
stovat si systmovmu administrtorovi.  Do t doby, jestlie C-h
nezobrazuje hlen o npovd v doln sti obrazovky, zkuste msto
toho pouvat klvesu F1 nebo M-x help RET.)

Nejzkladnj help pkaz je C-h c.  Stisknte C-h, znak c a klvesov
pkaz; Emacs pak zobraz velmi strun popis pkazu.

>> Stisknte C-h c C-p.
   Hlen by mlo vypadat asi takto

	C-p runs the command previous-line

To vm sdluje "jmno funkce".  Jmna funkc jsou pouvna zejmna pro
konfiguraci a roziovn Emacsu.  Ale protoe jmna funkc jsou volena
tak, aby naznaovala, co odpovdajc pkaz dl, mohou slouit tak
jako velmi strun dokumentace -- dostaten k tomu, aby vm pipomenula
pkazy, kter jste se ji nauili.

Vceznakov pkazy jako C-x C-s a (pokud nemte META, EDIT ani ALT
klvesu) <ESC>v jsou po C-h c povoleny tak.

K zskn vce informac o pkazu msto C-h c pouijte C-h k.

>> Stisknte C-h k C-p.

To zobraz dokumentaci k funkci a jej jmno v emacsovm okn.  A
vstup petete, stisknte C-x 1, abyste se textu npovdy zbavili.
Nemuste to dlat hned.  Mete chvli editovat a nahlet do textu
npovdy a teprve pak stisknout C-x 1.

Zde jsou dal uiten C-h volby:

   C-h f	Popis funkce.  Zadvte jmno funkce.

>> Zkuste napsat C-h f previous-line<Return>.
   To vype veker informace, kter Emacs m o funkci implementujc
   pkaz C-p.

Podobn pkaz C-h v zobraz dokumentaci promnn, jej hodnotu
mete nastavit a zmnit tm chovn Emacsu.  Jmno promnn zadte, a
se na n Emacs zept.

   C-h a	Pkazov apropos.  Zadejte klov slovo a Emacs vype
		vechny pkazy, jejich jmna obsahuj toto klov
		slovo.  Vechny tyto pkazy mohou bt vyvolny pomoc
		META-x.  Pro nkter pkazy pkazov apropos vype
		tak jedno nebo dvouznakov sekvence, kter provdj
		tent pkaz.

>> Napite C-h a file<Return>.

To zobraz v druhm okn seznam vech M-x pkaz obsahujcch "file" ve
svm nzvu.  Znakov pkazy jako C-x C-f uvidte vypsan vedle
odpovdajcch jmen pkaz jako find-file.

>> Stisknte C-M-v pro posun okna s npovdou.  Provete to nkolikrt.

>> Stisknte C-x 1 pro smazn okna s npovdou.

   C-h i	ten on-line manul (t Info).  Tento pkaz
		vs pepne do specilnho bufferu s nzvem `*info*',
		ve kterm mete st on-line manuly pro balky
		nainstalovan na vaem systmu.  Pokud stisknete
		m emacs <Return> mete si napklad pest manul
		k Emacsu.  Pokud jste dosud nikdy nepouvali Info,
		stisknte ? a Emacs vm pedstav hlavn monosti
		mdu pro Info.  A si tyto monosti prostudujete,
		mli byste pouvat Info manul Emacsu jako svoji
		primrn dokumentaci.


* ZVR
-------

Nezapomete, Emacs ukonte provedenm pkazu C-x C-c.  Pro doasn
odskok do shellu, ze kterho se do Emacsu mete opt vrtit,
pouijte C-z.

Zmrem tohoto tutorilu je bt srozumiteln vem novm uivatelm, take
narazte-li na nco nejasnho, tak neusedejte a neklate to za vinu sob
-- stujte si!


KOPROVN
----------

Tento tutoril vychz z dlouh ady emacsovch tutoril zahjen
tutorilem napsanm Stuartem Cracraftem pro pvodn Emacs.

Tato verze tutorilu je, podobn jako GNU Emacs, chrnna copyrightem a
je ena se svolenm distribuovat kopie za jistch podmnek:

Copyright (C) 1985, 1996, 1998, 2001, 2002, 2003, 2004,
   2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012  Free Software Foundation, Inc.

   Kadmu je zarueno prvo vytvet a distribuovat pesn kopie tohoto
   dokumentu tak, jak jej obdrel, na jakmkoliv mdiu, s tm, e bude
   zachovna tato poznmka o autorstv a poznmka o svolen a e
   distributor zaruuje pjemci prvo na dal redistribuci povolenou
   touto poznmkou.

   Je zarueno prvo distribuovat modifikovan verze tohoto dokumentu
   nebo jeho st pod ve uvedenmi podmnkami za pedpokladu, e
   obsahuje jasn poznmky uvdjc, kdo provedl posledn modifikace.

Podmnky pro koprovn Emacsu samotnho jsou sloitj, avak ve
stejnm duchu.  Pette si prosm soubor COPYING a pak pedvejte kopie
GNU Emacsu svm ptelm.  Pomhejte potrat softwarovou obstrukci
("vlastnictv") pouvnm, psanm a sdlenm free softwaru!

;;; Local Variables:
;;; coding: iso-latin-2
;;; End:

;;; arch-tag: 479ef577-3d4d-4384-aeea-9fe79d5e89ca
